@@ -4,6 +4,7 @@
   SPDX-FileCopyrightText: 2000, 2001, 2003, 2004 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2004-2025 Allen Winter <winter@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
@@ -116,7 +117,7 @@ public:
     void setCalendar(const Akonadi::ETMCalendar::Ptr &);
     Akonadi::ETMCalendar::Ptr calendar() const override;
 
-    QList<Akonadi::CollectionCalendar::Ptr> enabledCalendars() const;
+    QList<Akonadi::CollectionCalendar::Ptr> &enabledCalendars();
 
     Akonadi::CollectionCalendar::Ptr calendarForCollection(const Akonadi::Collection &collection) override;
 
@@ -139,11 +140,6 @@ public:
         return mRightFrame;
     }
 
-    QWidget *leftFrame() const
-    {
-        return mLeftFrame;
-    }
-
     NavigatorBar *navigatorBar() const
     {
         return mNavigatorBar;
@@ -247,8 +243,6 @@ Q_SIGNALS:
     /** Emitted when auto-archiving options were modified */
     void autoArchivingSettingsModified();
 
-    void newIncidenceChanger(Akonadi::IncidenceChanger *) override;
-
     void filtersUpdated(const QStringList &, int);
     void filterChanged();
 
@@ -298,7 +292,6 @@ public Q_SLOTS:
                   const QStringList &attendees = QStringList(),
                   const QStringList &attachmentMimetypes = QStringList(),
                   bool inlineAttachment = false);
-    void newFloatingEvent();
 
     /** Create a read-only viewer dialog for the supplied incidence.
         It calls the correct showXXX method */
@@ -317,7 +310,7 @@ public Q_SLOTS:
       journal view (as appropriate) and scrolling it to show the incidence.
       @param incidence The incidence to show.
     */
-    void showIncidenceContext(const Akonadi::Item &incidence);
+    void showIncidenceContext(const Akonadi::Item &item);
     bool showIncidenceContext(Akonadi::Item::Id id);
 
     /**
@@ -377,7 +370,7 @@ public Q_SLOTS:
       Delete the supplied incidence, including any dissociated instances, and
       all children (e.g. sub-todos).
       */
-    void deleteIncidenceFamily(const Akonadi::Item &todo);
+    void deleteIncidenceFamily(const Akonadi::Item &item);
 
     /** create new todo */
     void newTodo();
@@ -411,12 +404,12 @@ public Q_SLOTS:
 
     void configureCurrentView();
 
-    void toggleAlarm(const Akonadi::Item &incidence);
-    void toggleTodoCompleted(const Akonadi::Item &incidence);
+    void toggleAlarm(const Akonadi::Item &item);
+    void toggleTodoCompleted(const Akonadi::Item &item);
     void toggleOccurrenceCompleted(const Akonadi::Item &, const QDate &);
-    void copyIncidenceToResource(const Akonadi::Item &incidence, const Akonadi::Collection &col);
-    void moveIncidenceToResource(const Akonadi::Item &incidence, const Akonadi::Collection &col);
-    void dissociateOccurrences(const Akonadi::Item &incidence, QDate date);
+    void copyIncidenceToResource(const Akonadi::Item &item, const Akonadi::Collection &col);
+    void moveIncidenceToResource(const Akonadi::Item &item, const Akonadi::Collection &col);
+    void dissociateOccurrences(const Akonadi::Item &item, QDate date);
 
     /**
       Check if clipboard contains vCalendar event. The signal pasteEnabled() is
@@ -443,7 +436,7 @@ public Q_SLOTS:
 
     /** passes on the message that an event has changed to the currently
      * activated view so that it can make appropriate display changes. */
-    void changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType);
+    void changeIncidenceDisplay(const Akonadi::Item &item, Akonadi::IncidenceChanger::ChangeType);
 
     void slotCreateFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
@@ -484,15 +477,6 @@ public Q_SLOTS:
     /** Export as iCalendar file */
     void exportICalendar();
 
-    /** pop up a dialog to show an existing appointment. */
-    void appointment_show();
-    /**
-     * pop up an Appointment Dialog to edit an existing appointment. Get
-     * information on the appointment from the list of unique IDs that is
-     * currently in the View, called currIds.
-     */
-    void appointment_edit();
-
     /**
      * pop up dialog confirming deletion of currently selected event in the
      * View.
@@ -515,26 +499,14 @@ public Q_SLOTS:
     */
     bool makeChildrenIndependent(const Akonadi::Item &item);
 
-    /** Take ownership of selected event. */
-    void takeOverEvent();
-
-    /** set state of calendar to read-only
-        @param readOnly whether the calendar view should be set read-only or not
-    */
-    void setReadOnly(bool readOnly = true);
-
-    void eventUpdated(const Akonadi::Item &incidence);
-
     /* iTIP scheduling actions */
-    void schedule_publish(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_request(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_refresh(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_cancel(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_add(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_reply(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_counter(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_declinecounter(const Akonadi::Item &incidence = Akonadi::Item());
-    void schedule_forward(const Akonadi::Item &incidence = Akonadi::Item());
+    void schedule_publish(const Akonadi::Item &item = Akonadi::Item());
+    void schedule_request(const Akonadi::Item &item = Akonadi::Item());
+    void schedule_refresh(const Akonadi::Item &item = Akonadi::Item());
+    void schedule_cancel(const Akonadi::Item &item = Akonadi::Item());
+    void schedule_reply(const Akonadi::Item &item = Akonadi::Item());
+    void schedule_counter(const Akonadi::Item &item = Akonadi::Item());
+    void schedule_forward(const Akonadi::Item &item = Akonadi::Item());
     void mailFreeBusy(int daysToPublish = 30);
     void uploadFreeBusy();
 
@@ -544,8 +516,6 @@ public Q_SLOTS:
 
     void updateFilter();
 
-    void showIntro();
-
     void showDateNavigator(bool);
     void showTodoView(bool);
     void showEventViewer(bool);
@@ -559,6 +529,9 @@ public Q_SLOTS:
     /** Move the current view date to today */
     void goToday();
 
+    /** Move the current view date to date specified by the user */
+    void goSelectADate();
+
     /** Move to the next date(s) in the current view */
     void goNext();
 
@@ -567,12 +540,10 @@ public Q_SLOTS:
 
     void showLeftFrame(bool show = true);
 
-    void dialogClosing(const Akonadi::Item &incidence);
+    void processMainViewSelection(const Akonadi::Item &item, const QDate &date);
+    void processTodoListSelection(const Akonadi::Item &item, const QDate &date);
 
-    void processMainViewSelection(const Akonadi::Item &incidence, const QDate &date);
-    void processTodoListSelection(const Akonadi::Item &incidence, const QDate &date);
-
-    void processIncidenceSelection(const Akonadi::Item &incidence, const QDate &date);
+    void processIncidenceSelection(const Akonadi::Item &item, const QDate &date);
 
     void purgeCompleted();
 
@@ -581,11 +552,10 @@ public Q_SLOTS:
         Q_EMIT autoArchivingSettingsModified();
     }
 
-    void showErrorMessage(const QString &);
-    void schedule(KCalendarCore::iTIPMethod, const Akonadi::Item &incidence);
-    void addIncidenceOn(const Akonadi::Item &incidence, const QDate &);
-    void moveIncidenceTo(const Akonadi::Item &incidence, QDate);
-    void filterActivated(int filterNum);
+    void schedule(KCalendarCore::iTIPMethod, const Akonadi::Item &item);
+    void addIncidenceOn(const Akonadi::Item &itemadd, const QDate &);
+    void moveIncidenceTo(const Akonadi::Item &itemmove, QDate);
+    void filterActivated(int filterNo);
 
     void resourcesChanged();
 
@@ -598,7 +568,7 @@ public Q_SLOTS:
      * the week crosses months.  It's a QDate instead of uint so it can be
      * easily fed to KCalendarSystem's functions.
      */
-    void selectWeek(const QDate &week, const QDate &preferredMonth);
+    void selectWeek(const QDate &date, const QDate &preferredMonth);
 
     /**
      * Use as much of the full window as possible for the view.
@@ -611,6 +581,9 @@ public Q_SLOTS:
     void collectionSelected(const Akonadi::Collection &collection);
     void collectionDeselected(const Akonadi::Collection &collection);
 
+    /** Popup the "What's New" dialog **/
+    void slotWhatsNew();
+
 protected Q_SLOTS:
     /**
      * Select a view or adapt the current view to display the specified dates.
@@ -640,16 +613,15 @@ public:
     */
     QDate activeDate(bool fallbackToToday = false);
 
-    static void toggleCompleted(KCalendarCore::Todo::Ptr, const QDate &);
+    static void toggleCompleted(const KCalendarCore::Todo::Ptr &, const QDate &);
 
 protected:
-    int msgItemDelete(const Akonadi::Item &incidence);
+    int msgItemDelete(const Akonadi::Item &item);
 
     Akonadi::Item selectedTodo();
     IncidenceEditorNG::IncidenceDialog *incidenceDialog(const Akonadi::Item &);
 
-    void warningChangeFailed(const Akonadi::Item &);
-    void checkForFilteredChange(const Akonadi::Item &incidence);
+    void checkForFilteredChange(const Akonadi::Item &item);
 
     /**
       Adjust the given date/times by valid defaults (selection or configured
@@ -667,14 +639,14 @@ protected:
     void deleteChildren(const Akonadi::Item &);
 
 private Q_SLOTS:
-    void onCheckableProxyAboutToToggle(bool newState);
-    void onCheckableProxyToggled(bool newState);
     void onTodosPurged(bool success, int numDeleted, int numIgnored);
 
 private:
     Akonadi::Collection selectedCollection() const;
     Akonadi::Collection::List checkedCollections() const;
 
+    void agendaViewMenuSelector(const KCalendarCore::DateList &dates);
+
     int questionIndependentChildren(const Akonadi::Item &item);
 
     void createPrinter();
@@ -682,7 +654,7 @@ private:
     /**
      * Return the recurrence ID of  the occurrence of @p incidence displayed on @displayDate.
      */
-    static QDateTime recurrenceOnDate(KCalendarCore::Incidence::Ptr incidence, QDate displayDate);
+    static QDateTime recurrenceOnDate(const KCalendarCore::Incidence::Ptr &incidence, const QDate &displayDate);
 
     void dissociateOccurrence(const Akonadi::Item &item, const QDateTime &recurrenceId, bool thisAndFuture);
 
