@@ -127,10 +127,8 @@ void DateNavigator::selectWorkWeek(QDate d)
     emitSelected(/* preferredMonth= */ d);
 }
 
-void DateNavigator::selectToday()
+void DateNavigator::selectADate(QDate d)
 {
-    const QDate d = QDate::currentDate();
-
     const int dateCount = mSelectedDates.count();
 
     if (dateCount == 7) {
@@ -142,6 +140,11 @@ void DateNavigator::selectToday()
     }
 }
 
+void DateNavigator::selectToday()
+{
+    selectADate(QDate::currentDate());
+}
+
 void DateNavigator::selectPreviousYear()
 {
     QDate firstSelected = mSelectedDates.first();
@@ -156,25 +159,6 @@ void DateNavigator::selectPreviousMonth(const QDate &currentMonth, const QDate &
     shiftMonth(currentMonth, selectionLowerLimit, selectionUpperLimit, -1);
 }
 
-void DateNavigator::selectPreviousWeek()
-{
-    QDate firstSelected = mSelectedDates.first();
-    const int weekDay = firstSelected.dayOfWeek();
-    firstSelected = firstSelected.addDays(-7);
-
-    selectWeekByDay(weekDay, firstSelected);
-}
-
-void DateNavigator::selectNextWeek()
-{
-    QDate firstSelected = mSelectedDates.first();
-    const int weekDay = firstSelected.dayOfWeek();
-
-    firstSelected = firstSelected.addDays(7);
-
-    selectWeekByDay(weekDay, firstSelected);
-}
-
 void DateNavigator::shiftMonth(const QDate &currentMonth, const QDate &selectionLowerLimit, const QDate &selectionUpperLimit, int offset)
 {
     QDate firstSelected = mSelectedDates.first();
@@ -207,7 +191,7 @@ void DateNavigator::selectNextMonth(const QDate &currentMonth, const QDate &sele
 void DateNavigator::selectNextYear()
 {
     QDate firstSelected = mSelectedDates.first();
-    int weekDay = firstSelected.dayOfWeek();
+    int const weekDay = firstSelected.dayOfWeek();
     firstSelected = firstSelected.addYears(1);
 
     selectWeekByDay(weekDay, firstSelected);
@@ -240,7 +224,7 @@ void DateNavigator::selectMonth(int month)
 
     int day = firstSelected.day();
     firstSelected.setDate(firstSelected.year(), month, 1);
-    int days = firstSelected.daysInMonth();
+    int const days = firstSelected.daysInMonth();
     // As day we use either the selected date, or if the month has less days
     // than that, we use the max day of that month
     if (day > days) {
