@@ -29,7 +29,7 @@
 
 namespace
 {
-static const char mySearchDialogConfigGroupName[] = "SearchDialog";
+const char mySearchDialogConfigGroupName[] = "SearchDialog";
 }
 
 SearchDialog::SearchDialog(CalendarView *calendarview)
@@ -94,7 +94,8 @@ SearchDialog::SearchDialog(CalendarView *calendarview)
     //   connect(m_popupMenu, &KOEventPopupMenu::toggleTodoCompletedSignal, this,
     //           &SearchDialog::toggleTodoCompletedSignal);
 
-    for (const auto &calendar : m_calendarview->enabledCalendars()) {
+    const auto enabledCalendars = m_calendarview->enabledCalendars();
+    for (const auto &calendar : enabledCalendars) {
         m_listView->addCalendar(calendar);
     }
 
@@ -197,7 +198,8 @@ void SearchDialog::search(const QRegularExpression &regularExpression)
     KCalendarCore::Event::List events;
     KCalendarCore::Todo::List todos;
     KCalendarCore::Journal::List journals;
-    for (const auto &calendar : m_calendarview->enabledCalendars()) {
+    const auto enabledCalendars = m_calendarview->enabledCalendars();
+    for (const auto &calendar : enabledCalendars) {
         if (m_ui->dateRangeCheckbox->isChecked()) {
             if (m_ui->eventsCheck->isChecked()) {
                 if (m_ui->unfiltered->isChecked()) {
@@ -213,7 +215,7 @@ void SearchDialog::search(const QRegularExpression &regularExpression)
                 } else {
                     tmpTodos = calendar->todos();
                 }
-                for (const KCalendarCore::Todo::Ptr &todo : tmpTodos) {
+                for (const KCalendarCore::Todo::Ptr &todo : std::as_const(tmpTodos)) {
                     Q_ASSERT(todo);
                     if ((!todo->hasStartDate() && !todo->hasDueDate()) // undated
                         || (todo->hasStartDate() && (todo->dtStart().toLocalTime().date() >= startDt)
@@ -274,7 +276,8 @@ void SearchDialog::search(const QRegularExpression &regularExpression)
         Q_ASSERT(ev);
         auto collectionId = ev->customProperty("VOLATILE", "COLLECTION-ID").toLongLong();
         Akonadi::Item item;
-        for (const auto &calendar : m_calendarview->enabledCalendars()) {
+        const auto enabledCalendars2 = m_calendarview->enabledCalendars();
+        for (const auto &calendar : enabledCalendars2) {
             if (calendar->collection().id() == collectionId) {
                 item = calendar->item(ev);
             }
@@ -310,11 +313,10 @@ void SearchDialog::search(const QRegularExpression &regularExpression)
         }
         if (m_ui->attendeeCheck->isChecked()) {
             const KCalendarCore::Attendee::List lstAttendees = ev->attendees();
-            for (const KCalendarCore::Attendee &attendee : lstAttendees) {
-                if (regularExpression.match(attendee.fullName()).hasMatch()) {
-                    m_matchedEvents.append(item);
-                    break;
-                }
+            if (std::ranges::any_of(lstAttendees, [regularExpression](const KCalendarCore::Attendee &attendee) {
+                    return regularExpression.match(attendee.fullName()).hasMatch();
+                })) {
+                m_matchedEvents.append(item);
             }
         }
     }
@@ -324,7 +326,7 @@ void SearchDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(775, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(mySearchDialogConfigGroupName));
+    KConfigGroup const group(KSharedConfig::openStateConfig(), QLatin1StringView(mySearchDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 
