@@ -120,26 +120,11 @@ QDateTime BaseView::startDateTime() const
     return d->startDateTime;
 }
 
-QDateTime BaseView::endDateTime() const
-{
-    return d->endDateTime;
-}
-
-QDateTime BaseView::actualStartDateTime() const
-{
-    return d->actualStartDateTime;
-}
-
-QDateTime BaseView::actualEndDateTime() const
-{
-    return d->actualEndDateTime;
-}
-
 void BaseView::showConfigurationDialog(QWidget *)
 {
 }
 
-QByteArray BaseView::identifier() const
+QByteArray &BaseView::identifier()
 {
     return d->identifier;
 }
@@ -242,11 +227,11 @@ Akonadi::CollectionCalendar::Ptr BaseView::calendarForCollection(Akonadi::Collec
 Akonadi::CollectionCalendar::Ptr BaseView::calendarForIncidence(const KCalendarCore::Incidence::Ptr &incidence) const
 {
     bool ok = false;
-    const auto collectionId = incidence->customProperty("VOLATILE", "COLLECTION-ID").toLongLong(&ok);
-    if (!ok || collectionId < 0) {
+    const auto colId = incidence->customProperty("VOLATILE", "COLLECTION-ID").toLongLong(&ok);
+    if (!ok || colId < 0) {
         return {};
     }
 
-    return calendarForCollection(collectionId);
+    return calendarForCollection(colId);
 }
 #include "moc_baseview.cpp"
