@@ -12,10 +12,6 @@
 
 #include <KPluginFactory>
 
-#include <CalendarSupport/IdentityManager>
-
-#include "korganizer_debug.h"
-
 #include <QDBusConnectionInterface>
 
 KOCore *KOCore::mSelf = nullptr;
@@ -52,12 +48,12 @@ EventViews::CalendarDecoration::Decoration *KOCore::loadCalendarDecoration(const
     return KPluginFactory::instantiatePlugin<EventViews::CalendarDecoration::Decoration>(service).plugin;
 }
 
-void KOCore::addXMLGUIClient(QWidget *wdg, KXMLGUIClient *guiclient)
+void KOCore::addXMLGUIClient(QWidget *wdg, KXMLGUIClient *guiclient) /* cppcheck-suppress constParameterPointer */
 {
     mXMLGUIClients.insert(wdg, guiclient);
 }
 
-void KOCore::removeXMLGUIClient(QWidget *wdg)
+void KOCore::removeXMLGUIClient(QWidget *wdg) /* cppcheck-suppress constParameterPointer */
 {
     mXMLGUIClients.remove(wdg);
 }
@@ -68,8 +64,8 @@ KXMLGUIClient *KOCore::xmlguiClient(QWidget *wdg) const
         return nullptr;
     }
 
-    QWidget *topLevel = wdg->topLevelWidget();
-    QMap<QWidget *, KXMLGUIClient *>::ConstIterator it = mXMLGUIClients.find(topLevel);
+    QWidget *topLevel = wdg->topLevelWidget(); /* cppcheck-suppress constVariablePointer */
+    QMap<QWidget *, KXMLGUIClient *>::ConstIterator const it = mXMLGUIClients.find(topLevel);
     if (it != mXMLGUIClients.constEnd()) {
         return it.value();
     }
@@ -85,7 +81,7 @@ EventViews::CalendarDecoration::Decoration::List KOCore::loadCalendarDecorations
         mCalendarDecorations.clear();
         const QList<KPluginMetaData> plugins = availableCalendarDecorations();
         for (const auto &plugin : plugins) {
-            QString name = plugin.pluginId();
+            QString const name = plugin.pluginId();
             if (selectedPlugins.contains(name)) {
                 EventViews::CalendarDecoration::Decoration *d = loadCalendarDecoration(plugin);
                 mCalendarDecorations.append(d);
@@ -111,8 +107,3 @@ void KOCore::reloadPlugins()
     unloadPlugins();
     loadCalendarDecorations();
 }
-
-KIdentityManagementCore::IdentityManager *KOCore::identityManager()
-{
-    return CalendarSupport::IdentityManager::self();
-}
