@@ -38,7 +38,6 @@ const int KODayMatrix::NUMDAYS = 42;
 
 KODayMatrix::KODayMatrix(QWidget *parent)
     : QFrame(parent)
-    , mStartDate()
 {
     // initialize dynamic arrays
     mDays = new QDate[NUMDAYS];
@@ -88,7 +87,7 @@ QColor KODayMatrix::getShadedColor(const QColor &color) const
 
 KODayMatrix::~KODayMatrix()
 {
-    for (const auto &calendar : mCalendars) {
+    for (const auto &calendar : std::as_const(mCalendars)) {
         calendar->unregisterObserver(this);
     }
 
@@ -96,37 +95,6 @@ KODayMatrix::~KODayMatrix()
     delete[] mDayLabels;
 }
 
-void KODayMatrix::addSelectedDaysTo(KCalendarCore::DateList &selDays)
-{
-    if (mSelStart == NOSELECTION) {
-        return;
-    }
-
-    // cope with selection being out of matrix limits at top (< 0)
-    int i0 = mSelStart;
-    if (i0 < 0) {
-        for (int i = i0; i < 0; ++i) {
-            selDays.append(mDays[0].addDays(i));
-        }
-        i0 = 0;
-    }
-
-    // cope with selection being out of matrix limits at bottom (> NUMDAYS-1)
-    if (mSelEnd > NUMDAYS - 1) {
-        for (int i = i0; i <= NUMDAYS - 1; ++i) {
-            selDays.append(mDays[i]);
-        }
-        for (int i = NUMDAYS; i < mSelEnd; ++i) {
-            selDays.append(mDays[0].addDays(i));
-        }
-    } else {
-        // apply normal routine to selection being entirely within matrix limits
-        for (int i = i0; i <= mSelEnd; ++i) {
-            selDays.append(mDays[i]);
-        }
-    }
-}
-
 void KODayMatrix::setSelectedDaysFrom(QDate start, QDate end)
 {
     if (mStartDate.isValid()) {
@@ -183,7 +151,7 @@ void KODayMatrix::updateView(QDate actdate)
         // reset index of selection according to shift of starting date from
         // startdate to actdate.
         if (mSelStart != NOSELECTION) {
-            int tmp = actdate.daysTo(mStartDate);
+            int const tmp = actdate.daysTo(mStartDate);
             // shift selection if new one would be visible at least partly !
             if (mSelStart + tmp < NUMDAYS && mSelEnd + tmp >= 0) {
                 // nested if required for next X display pushed from a different month
@@ -219,7 +187,7 @@ void KODayMatrix::updateView(QDate actdate)
     QMap<QDate, QStringList> holidaysByDate = KOGlobals::self()->holiday(mDays[0], mDays[NUMDAYS - 1]);
     for (int i = 0; i < NUMDAYS; ++i) {
         // if it is a holy day then draw it red. Sundays are consider holidays, too
-        QStringList holidays = holidaysByDate[mDays[i]];
+        QStringList const holidays = holidaysByDate[mDays[i]];
         QString holiStr;
 
         if (!holidays.isEmpty()) {
@@ -253,10 +221,11 @@ void KODayMatrix::updateIncidences()
 
 void KODayMatrix::updateJournals()
 {
-    for (const auto &calendar : mCalendars) {
-        for (const KCalendarCore::Incidence::Ptr &inc : calendar->incidences()) {
+    for (const auto &calendar : std::as_const(mCalendars)) {
+        const KCalendarCore::Incidence::List incidences = calendar->incidences();
+        for (const KCalendarCore::Incidence::Ptr &inc : incidences) {
             Q_ASSERT(inc);
-            QDate d = inc->dtStart().toLocalTime().date();
+            QDate const d = inc->dtStart().toLocalTime().date();
             if (inc->type() == KCalendarCore::Incidence::TypeJournal && d >= mDays[0] && d <= mDays[NUMDAYS - 1] && !mEvents.contains(d)) {
                 mEvents.append(d);
             }
@@ -280,15 +249,16 @@ void KODayMatrix::updateJournals()
 void KODayMatrix::updateTodos()
 {
     QDate d;
-    for (const auto &calendar : mCalendars) {
-        for (const KCalendarCore::Todo::Ptr &t : calendar->todos()) {
+    for (const auto &calendar : std::as_const(mCalendars)) {
+        const KCalendarCore::Todo::List todos = calendar->todos();
+        for (const KCalendarCore::Todo::Ptr &t : todos) {
             if (mEvents.count() == NUMDAYS) {
                 // No point in wasting cpu, all days are bold already
                 break;
             }
             Q_ASSERT(t);
             if (t->hasDueDate()) {
-                ushort recurType = t->recurrenceType();
+                ushort const recurType = t->recurrenceType();
 
                 if (t->recurs() && !(recurType == KCalendarCore::Recurrence::rDaily && !KOPrefs::instance()->mDailyRecur)
                     && !(recurType == KCalendarCore::Recurrence::rWeekly && !KOPrefs::instance()->mWeeklyRecur)) {
@@ -321,34 +291,34 @@ void KODayMatrix::updateEvents()
         return;
     }
 
-    for (const auto &calendar : mCalendars) {
+    for (const auto &calendar : std::as_const(mCalendars)) {
         const auto eventlist = calendar->events(mDays[0], mDays[NUMDAYS - 1], calendar->timeZone());
-        for (const KCalendarCore::Event::Ptr &event : eventlist) {
+        for (const KCalendarCore::Event::Ptr &ev : eventlist) {
             if (mEvents.count() == NUMDAYS) {
                 // No point in wasting cpu, all days are bold already
                 break;
             }
 
-            Q_ASSERT(event);
-            const ushort recurType = event->recurrenceType();
-            const QDateTime dtStart = event->dtStart().toLocalTime();
+            Q_ASSERT(ev);
+            const ushort recurType = ev->recurrenceType();
+            const QDateTime dtStart = ev->dtStart().toLocalTime();
 
             // timed incidences occur in
             //   [dtStart(), dtEnd()[. All-day incidences occur in [dtStart(), dtEnd()]
             // so we subtract 1 second in the timed case
-            const int secsToAdd = event->allDay() ? 0 : -1;
-            const QDateTime dtEnd = event->dtEnd().toLocalTime().addSecs(secsToAdd);
+            const int secsToAdd = ev->allDay() ? 0 : -1;
+            const QDateTime dtEnd = ev->dtEnd().toLocalTime().addSecs(secsToAdd);
 
             if (!(recurType == KCalendarCore::Recurrence::rDaily && !KOPrefs::instance()->mDailyRecur)
                 && !(recurType == KCalendarCore::Recurrence::rWeekly && !KOPrefs::instance()->mWeeklyRecur)) {
                 KCalendarCore::DateTimeList timeDateList;
-                const bool isRecurrent = event->recurs();
+                const bool isRecurrent = ev->recurs();
                 const int eventDuration = dtStart.daysTo(dtEnd);
 
                 if (isRecurrent) {
                     // Its a recurring event, find out in which days it occurs
-                    timeDateList = event->recurrence()->timesInInterval(QDateTime(mDays[0], {}, QTimeZone::LocalTime),
-                                                                        QDateTime(mDays[NUMDAYS - 1], {}, QTimeZone::LocalTime));
+                    timeDateList = ev->recurrence()->timesInInterval(QDateTime(mDays[0], {}, QTimeZone::LocalTime),
+                                                                     QDateTime(mDays[NUMDAYS - 1], {}, QTimeZone::LocalTime));
                 } else {
                     if (dtStart.date() >= mDays[0]) {
                         timeDateList.append(dtStart);
@@ -448,28 +418,28 @@ bool KODayMatrix::event(QEvent *event)
         auto helpEvent = static_cast<QHelpEvent *>(event);
 
         // calculate which cell of the matrix the mouse is in
-        QRect sz = frameRect();
-        int dheight = sz.height() * 7 / 42;
-        int dwidth = sz.width() / 7;
-        int row = helpEvent->pos().y() / dheight;
-        int col = helpEvent->pos().x() / dwidth;
+        QRect const sz = frameRect();
+        int const dheight = sz.height() * 7 / 42;
+        int const dwidth = sz.width() / 7;
+        int const row = helpEvent->pos().y() / dheight;
+        int const col = helpEvent->pos().x() / dwidth;
 
         // show holiday names only
-        QString tipText = getHolidayLabel(col + row * 7);
+        QString const tipText = getHolidayLabel(col + row * 7);
         if (!tipText.isEmpty()) {
             QToolTip::showText(helpEvent->globalPos(), tipText);
         } else {
             QToolTip::hideText();
         }
     }
-    return QWidget::event(event);
+    return QFrame::event(event);
 }
 
 void KODayMatrix::mousePressEvent(QMouseEvent *e)
 {
     mSelStart = getDayIndexFrom(e->position().toPoint().x(), e->position().toPoint().y());
     if (e->button() == Qt::RightButton) {
-        popupMenu(mDays[mSelStart], mDays[mSelEnd]);
+        popupMenu(mDays[mSelStart]);
     } else if (e->button() == Qt::LeftButton) {
         if (mSelStart > NUMDAYS - 1) {
             mSelStart = NUMDAYS - 1;
@@ -477,16 +447,16 @@ void KODayMatrix::mousePressEvent(QMouseEvent *e)
         mSelInit = mSelStart;
     }
 }
-void KODayMatrix::popupMenu(const QDate &date, const QDate &date2)
+void KODayMatrix::popupMenu(const QDate &date)
 {
     QMenu popup(this);
     popup.setTitle(date.toString());
-    QAction *newEventAction = popup.addAction(QIcon::fromTheme(QStringLiteral("appointment-new")), i18n("New E&vent…"));
-    QAction *newTodoAction = popup.addAction(QIcon::fromTheme(QStringLiteral("task-new")), i18n("New &To-do…"));
-    QAction *newJournalAction = popup.addAction(QIcon::fromTheme(QStringLiteral("journal-new")), i18n("New &Journal…"));
-    QAction *ret = popup.exec(QCursor::pos());
+    const QAction *newEventAction = popup.addAction(QIcon::fromTheme(QStringLiteral("appointment-new")), i18n("New E&vent…"));
+    const QAction *newTodoAction = popup.addAction(QIcon::fromTheme(QStringLiteral("task-new")), i18n("New &To-do…"));
+    const QAction *newJournalAction = popup.addAction(QIcon::fromTheme(QStringLiteral("journal-new")), i18n("New &Journal…"));
+    const QAction *ret = popup.exec(QCursor::pos());
     if (ret == newEventAction) {
-        Q_EMIT newEventSignal(date, date2);
+        Q_EMIT newEventSignal(date);
     } else if (ret == newTodoAction) {
         Q_EMIT newTodoSignal(date);
     } else if (ret == newJournalAction) {
@@ -593,16 +563,16 @@ void KODayMatrix::dragMoveEvent(QDragMoveEvent *e)
     e->accept();
 }
 
-void KODayMatrix::dragLeaveEvent(QDragLeaveEvent *dl)
+void KODayMatrix::dragLeaveEvent(QDragLeaveEvent *e)
 {
-    Q_UNUSED(dl)
+    Q_UNUSED(e)
     //  setPalette(oldPalette);
     //  update();
 }
 
 void KODayMatrix::dropEvent(QDropEvent *e)
 {
-    QList<QUrl> urls = (e->mimeData()->urls());
+    QList<QUrl> const urls = (e->mimeData()->urls());
     // qCDebug(KORGANIZER_LOG)<<" urls :"<<urls;
     if (urls.isEmpty()) {
         e->ignore();
@@ -610,7 +580,7 @@ void KODayMatrix::dropEvent(QDropEvent *e)
     }
     // For the moment support 1 url
     if (urls.count() >= 1) {
-        QUrl res = urls.at(0);
+        QUrl const &res = urls.at(0);
 
         auto job = new Akonadi::ItemFetchJob(Akonadi::Item::fromUrl(res));
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
@@ -619,16 +589,16 @@ void KODayMatrix::dropEvent(QDropEvent *e)
         if (job->exec()) {
             items = job->items();
         }
-        bool exist = items.at(0).isValid();
+        bool const exist = items.at(0).isValid();
         int action = DRAG_CANCEL;
-        Qt::KeyboardModifiers keyboardModifiers = e->modifiers();
+        Qt::KeyboardModifiers const keyboardModifiers = e->modifiers();
         if (keyboardModifiers & Qt::ControlModifier) {
             action = DRAG_COPY;
         } else if (keyboardModifiers & Qt::ShiftModifier) {
             action = DRAG_MOVE;
         } else {
-            QAction *copy = nullptr;
-            QAction *move = nullptr;
+            const QAction *copy = nullptr;
+            const QAction *move = nullptr;
             auto menu = new QMenu(this);
             if (exist) {
                 move = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("&Move"));
@@ -641,7 +611,7 @@ void KODayMatrix::dropEvent(QDropEvent *e)
             menu->addSeparator();
             /*QAction *cancel =*/
             menu->addAction(QIcon::fromTheme(QStringLiteral("process-stop")), i18n("&Cancel"));
-            QAction *a = menu->exec(QCursor::pos());
+            const QAction *a = menu->exec(QCursor::pos());
             if (a == copy) {
                 action = DRAG_COPY;
             } else if (a == move) {
@@ -652,7 +622,7 @@ void KODayMatrix::dropEvent(QDropEvent *e)
 
         if (action == DRAG_COPY || action == DRAG_MOVE) {
             e->accept();
-            int idx = getDayIndexFrom(e->position().toPoint().x(), e->position().toPoint().y());
+            int const idx = getDayIndexFrom(e->position().toPoint().x(), e->position().toPoint().y());
 
             if (action == DRAG_COPY) {
                 Q_EMIT incidenceDropped(items.at(0), mDays[idx]);
@@ -677,7 +647,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
     int column;
     const bool isRTL = KOGlobals::self()->reverseLayout();
 
-    QPalette pal = palette();
+    QPalette const pal = palette();
 
     p.begin(this);
 
@@ -721,7 +691,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
                 }
                 // draw last block from left to mSelEnd
                 if (mSelEnd / 7 < 6) {
-                    int selectionWidth = mSelEnd - 7 * (mSelEnd / 7) + 1;
+                    int const selectionWidth = mSelEnd - 7 * (mSelEnd / 7) + 1;
                     p.fillRect(isRTL ? (7 - selectionWidth) * dayWidth : 0,
                                (row + selectionHeight) * dayHeight,
                                selectionWidth * dayWidth,
@@ -815,7 +785,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
             p.setPen(actcol);
         }
         // reset bold font to plain font
-        if (mEvents.contains(mDays[i]) > 0) {
+        if (mEvents.contains(mDays[i])) {
             QFont myFont = font();
             myFont.setBold(false);
             p.setFont(myFont);
@@ -830,7 +800,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
 
 void KODayMatrix::resizeEvent(QResizeEvent *)
 {
-    QRect sz = frameRect();
+    QRect const sz = frameRect();
     mDaySize.setHeight(sz.height() * 7 / NUMDAYS);
     mDaySize.setWidth(sz.width() / 7);
 }
