@@ -105,18 +105,12 @@ public:
      */
     QString getHolidayLabel(int offset) const;
 
-    /**
-     * Adds all actual selected days from mSelStart to mSelEnd to the supplied
-     * DateList.
-     */
-    void addSelectedDaysTo(KCalendarCore::DateList &);
-
     /**
      * Sets the actual to be displayed selection in the day matrix starting
      * from start and ending with end. Theview must be manually updated by
      * calling repaint. (?)
-     * @param start start of the new selection
-     * @param end end date of the new selection
+     * @param start the new selection starting date
+     * @param end the new selection ending date
      */
     void setSelectedDaysFrom(QDate start, QDate end);
 
@@ -125,31 +119,6 @@ public:
     */
     void clearSelection();
 
-    /** Is today visible in the view? Keep this in sync with
-     * the values today (below) can take.
-     */
-    [[nodiscard]] bool isTodayVisible() const
-    {
-        return mToday >= 0;
-    }
-
-    /**
-     * If today is visible, then we can find out if today is
-     * near the beginning or the end of the month.
-     * This is dependent on today remaining the index
-     * in the array of visible dates and going from
-     * top left (0) to bottom right (41).
-     */
-    [[nodiscard]] bool isBeginningOfMonth() const
-    {
-        return mToday <= 8;
-    }
-
-    [[nodiscard]] bool isEndOfMonth() const
-    {
-        return mToday >= 27;
-    }
-
     /**
      *  Reimplemented from Akonadi::ETMCalendar
      *  They set mPendingChanges to true
@@ -188,7 +157,7 @@ Q_SIGNALS:
      */
     void selected(const KCalendarCore::DateList &daylist);
 
-    void newEventSignal(const QDate &date, const QDate &Date);
+    void newEventSignal(const QDate &date);
     void newTodoSignal(const QDate &date);
     void newJournalSignal(const QDate &date);
 
@@ -235,7 +204,7 @@ private:
     /**
      * Pop-up a context menu for creating a new Event, To-do, or Journal.
      */
-    void popupMenu(const QDate &date, const QDate &date2);
+    void popupMenu(const QDate &date);
 
     /** returns the index of the day located at the matrix's widget (x,y) position.
      *
