@@ -16,7 +16,7 @@ class SpecialdatesPlugin : public KontactInterface::Plugin
 {
     Q_OBJECT
 public:
-    SpecialdatesPlugin(KontactInterface::Core *core, const QVariantList &);
+    SpecialdatesPlugin(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &);
     ~SpecialdatesPlugin() override;
 
     int weight() const override
@@ -34,4 +34,3 @@ protected:
         return nullptr;
     }
 };
-
