@@ -8,7 +8,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include "kprefsdialog.h"
 #include <QSet>
 class QTreeWidget;
@@ -21,11 +20,7 @@ class KOPrefsDialogPlugins : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KOPrefsDialogPlugins(QWidget *parent, const QVariantList &args = {});
-#else
-    explicit KOPrefsDialogPlugins(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
-#endif
+    explicit KOPrefsDialogPlugins(QObject *parent, const KPluginMetaData &data);
     ~KOPrefsDialogPlugins() override;
 
 protected Q_SLOTS:
