@@ -102,8 +102,6 @@ public:
     void readConfig() override;
     void writeConfig() override;
 
-    QList<QWidget *> widgets() const override;
-
 private:
     void init(QWidget *parent);
     KConfigSkeletonItem *mItem = nullptr;
@@ -144,8 +142,6 @@ public:
     void readConfig() override;
     void writeConfig() override;
 
-    QList<QWidget *> widgets() const override;
-
 private:
     KConfigSkeleton::ItemInt *mItem = nullptr;
 
@@ -256,11 +252,6 @@ public:
     */
     QLabel *label();
 
-    /**
-      Return KDateComboBox used by this widget.
-    */
-    KDateComboBox *dateEdit();
-
     void readConfig() override;
     void writeConfig() override;
 
@@ -411,8 +402,6 @@ public:
     void readConfig() override;
     void writeConfig() override;
 
-    QList<QWidget *> widgets() const override;
-
 private:
     KConfigSkeleton::ItemEnum *mItem = nullptr;
 
@@ -449,7 +438,6 @@ public:
 
     KComboBox *comboBox();
 
-    QList<QWidget *> widgets() const override;
     /**
       Return QLabel used by this control element.
     */
@@ -498,8 +486,6 @@ public:
     void readConfig() override;
     void writeConfig() override;
 
-    QList<QWidget *> widgets() const override;
-
 private:
     KConfigSkeleton::ItemString *mItem = nullptr;
 
@@ -547,8 +533,6 @@ public:
     void readConfig() override;
     void writeConfig() override;
 
-    QList<QWidget *> widgets() const override;
-
 private:
     KConfigSkeleton::ItemPath *mItem = nullptr;
 
@@ -570,7 +554,7 @@ public:
     /**
       Create a KPrefsWidManager object for a KPrefs object.
 
-      @param prefs  KPrefs object used to access te configuration.
+      @param prefs  KPrefs object used to access the configuration.
     */
     explicit KPrefsWidManager(KConfigSkeleton *prefs);
 
@@ -613,14 +597,6 @@ public:
     */
     KPrefsWidInt *addWidInt(KConfigSkeleton::ItemInt *item, QWidget *parent = nullptr);
 
-    /**
-      Register a @ref KPrefsWidDate object.
-
-      @param item    The KConfigSkeletonItem representing the preferences entry.
-      @param parent  Parent widget.
-    */
-    KPrefsWidDate *addWidDate(KConfigSkeleton::ItemDateTime *item, QWidget *parent = nullptr);
-
     /**
       Register a @ref KPrefsWidTime object.
 
@@ -682,14 +658,6 @@ public:
     */
     KPrefsWidPath *addWidPath(KConfigSkeleton::ItemPath *item, QWidget *parent = nullptr, const QString &filter = QString(), KFile::Modes mode = KFile::File);
 
-    /**
-      Register a password @ref KPrefsWidString object, with echomode set to KLineEdit::Password.
-
-      @param item    The KConfigSkeletonItem representing the preferences entry.
-      @param parent  Parent widget.
-    */
-    KPrefsWidString *addWidPassword(KConfigSkeleton::ItemString *item, QWidget *parent = nullptr);
-
     /**
       Register a @ref KPrefsWidFont object.
 
@@ -734,7 +702,7 @@ public:
     /**
       Create a KPrefsDialog for a KPrefs object.
 
-      @param prefs  KPrefs object used to access te configuration.
+      @param prefs  KPrefs object used to access the configuration.
       @param parent Parent widget.
       @param name   Widget name.
       @param modal  true, if dialog has to be modal, false for non-modal.
@@ -746,8 +714,6 @@ public:
     */
     ~KPrefsDialog() override;
 
-    void autoCreate();
-
 public Q_SLOTS:
     /** Set all widgets to default values. */
     void setDefaults();
