@@ -27,12 +27,11 @@
 
 namespace
 {
-static const char myQuickviewConfigGroupName[] = "Quickview";
+const char myQuickviewConfigGroupName[] = "Quickview";
 }
 
 Quickview::Quickview(const Akonadi::CollectionCalendar::Ptr &calendar, const QString &title)
-    : QDialog()
-    , mUi(new Ui_quickview)
+    : mUi(new Ui_quickview)
 {
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     auto mainWidget = new QWidget(this);
@@ -95,7 +94,7 @@ void Quickview::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(775, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myQuickviewConfigGroupName));
+    KConfigGroup const group(KSharedConfig::openStateConfig(), QLatin1StringView(myQuickviewConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 
