@@ -24,37 +24,37 @@ public:
     explicit MonthView(QWidget *parent = nullptr);
     ~MonthView() override;
 
-    Q_REQUIRED_RESULT int currentDateCount() const override;
-    Q_REQUIRED_RESULT int currentMonth() const;
+    [[nodiscard]] int currentDateCount() const override;
+    [[nodiscard]] int currentMonth() const;
 
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() override;
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() override;
 
     /** Returns dates of the currently selected events */
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() override;
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() override;
 
-    Q_REQUIRED_RESULT QDateTime selectionStart() override;
+    [[nodiscard]] QDateTime selectionStart() override;
 
-    Q_REQUIRED_RESULT QDateTime selectionEnd() override;
-    Q_REQUIRED_RESULT bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) override;
+    [[nodiscard]] QDateTime selectionEnd() override;
+    [[nodiscard]] bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) override;
 
     /**
      * Returns the average date in the view
      */
-    Q_REQUIRED_RESULT QDate averageDate() const;
+    [[nodiscard]] QDate averageDate() const;
 
-    Q_REQUIRED_RESULT bool usesFullWindow() override;
+    [[nodiscard]] bool usesFullWindow() override;
 
-    Q_REQUIRED_RESULT bool supportsDateRangeSelection() override;
+    [[nodiscard]] bool supportsDateRangeSelection() override;
 
-    Q_REQUIRED_RESULT CalendarSupport::CalPrinterBase::PrintType printType() const override;
+    [[nodiscard]] CalendarSupport::CalPrinterBase::PrintType printType() const override;
 
-    Q_REQUIRED_RESULT int maxDatesHint() const override;
+    [[nodiscard]] int maxDatesHint() const override;
 
     void setTypeAheadReceiver(QObject *o) override;
 
     void setDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate()) override;
 
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) override;
+    void setModel(QAbstractItemModel *model) override;
 
     void setIncidenceChanger(Akonadi::IncidenceChanger *changer) override;
 
@@ -67,6 +67,9 @@ public Q_SLOTS:
 
     void updateConfig() override;
 
+    void calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+    void calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+
 Q_SIGNALS:
     void fullViewChanged(bool enabled);
 
