@@ -16,12 +16,12 @@ QList<KLazyLocalizedString> WhatsNewTranslations::lastNewFeatures() const
 {
     const QList<KLazyLocalizedString> info{
         kli18n("Add What's New menu"),
+        kli18n("The current view is remembered"),
         kli18n("Add a Date Picker dialog available on the Go menu"),
         kli18n("Agenda view: consolidated the \"Day\", \"Next X Days\", \"Work Schedule\", \"Week\" time ranges into the Agenda tool button"),
         kli18n("Agenda view: added timelabels context menu option to toggle a 24-hour (military style) clock"),
         kli18n("Agenda view: added context menu to create new Event or To-do"),
         kli18n("To-do view: added context menu options for toggling completion and reminders"),
-        kli18n("To-do view: remove the (redundant) to-do list from the sidebar"),
         kli18n("To-do view: save/restore fullview setting"),
         kli18n("To-do view: save/restore flatview setting"),
         kli18n("Date navigator: added an option in the Configure->Views settings for hiding the week numbers"),
