@@ -132,7 +132,7 @@ void NavigatorBar::selectMonthFromMenu()
         menu->setActiveAction(activateAction);
     }
     month = 0;
-    QAction *selectedAct = menu->exec(mMonth->mapToGlobal(QPoint(0, 0)));
+    const QAction *selectedAct = menu->exec(mMonth->mapToGlobal(QPoint(0, 0)));
     if (selectedAct && (selectedAct != activateAction)) {
         for (int i = 0; i < months; ++i) {
             if (act[i] == selectedAct) {
@@ -152,8 +152,8 @@ void NavigatorBar::selectMonthFromMenu()
 void NavigatorBar::selectYearFromMenu()
 {
     int year = mDate.year();
-    int years = 11; // odd number (show a few years ago -> a few years from now)
-    int minYear = year - (years / 3);
+    int const years = 11; // odd number (show a few years ago -> a few years from now)
+    int const minYear = year - (years / 3);
 
     auto menu = new QMenu(mYear);
     QList<QAction *> act;
@@ -174,14 +174,14 @@ void NavigatorBar::selectYearFromMenu()
         menu->setActiveAction(activateAction);
     }
     year = 0;
-    QAction *selectedAct = menu->exec(mYear->mapToGlobal(QPoint(0, 0)));
+    const QAction *selectedAct = menu->exec(mYear->mapToGlobal(QPoint(0, 0)));
     if (selectedAct && (selectedAct != activateAction)) {
-        int y = minYear;
+        int yearCount = minYear;
         for (int i = 0; i < years; ++i) {
             if (act[i] == selectedAct) {
-                year = y;
+                year = yearCount;
             }
-            y++;
+            yearCount++;
         }
     }
     qDeleteAll(act);
